Changes — SoL 4 developers documentation

# Changes

## 4.0a4 (2020-01-18)

- New association between clubs and users: now a user may add a championship/tourney/rating/player only to clubs he either owns or is associated with

- Add a link to send an email to the instance' admin on the login panel

## 4.0a3 (2020-01-13)

- Use a three-state flag for the player's agreed privacy: when not explicitly expressed, SoL assumes they are publicly discernible if they participated to tournaments after January 1, 2020

- Player's first and last names must be longer that one single character

## 4.0a2 (2020-01-11)

- Fix issue with UI language negotiation

- Use the better maintained Fomantic-UI fork of Semantic-UI in the “Lit” interface

- New tournaments delay compatriots pairing option

- Technicalities:

  - Official repository is now https://gitlab.com/metapensiero/SoL

  - NixOS recipes (thanks to azazel@metapensiero.it)

## 4.0a1 (2018-08-06)

Warning

Backward incompatible version

This release uses a different algorithm to crypt the user's password: for this reason previous account credentials cannot be restored and shall require manual intervention.

It's not possible to upgrade an existing SoL3 database to the latest version.

However, SoL4 is able to import a backup of a SoL3 database made by `soladmin backup`.

- Different layout for matches and results printouts, using two columns for the competitors to improve readability (suggested by Daniele)

- New tournaments retirements policy

- New "women" and "under xx" tourney's ranking printouts

- New “self sign up” procedure

- New “forgot password” procedure

- New "agreed privacy" on players

- Somewhat prettier “Lit” interface, using Semantic-UI tables

- Technicalities:

  - Development moved to GitLab

  - Officially supported on Python 3.6 and 3.7, not anymore on <=3.5

  - Shiny new pytest-based tests suite

  - Uses python-rapidjson instead nssjson, as I officially declared the latter as abandoned

  - Uses PyNaCl instead of cryptacular, as the former is much better maintained

  - "Users" are now a separated entity from "players": now the login "username" is a mandatory email and the password must be longer than five characters (was three before)